[Date Prev][Date Next] [Thread Prev][Thread Next] [Date Index] [Thread Index]

Bug#925357: marked as done (unblock: tomoyo-tools/2.6.0-20190305-1)



Your message dated Tue, 2 Apr 2019 15:21:19 +0900
with message-id <20190402152119.0c85ec228d1bfbae6d6d8d45@iijmio-mail.jp>
and subject line Re: Bug#925357: unblock: tomoyo-tools/2.6.0-20190305-1
has caused the Debian Bug report #925357,
regarding unblock: tomoyo-tools/2.6.0-20190305-1
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact owner@bugs.debian.org
immediately.)


-- 
925357: https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=925357
Debian Bug Tracking System
Contact owner@bugs.debian.org with problems
--- Begin Message ---
Package: release.debian.org
Severity: wishlist
User: release.debian.org@packages.debian.org
Usertags: unblock

Please unblock package tomoyo-tools

* I'd like to push tomoyo 2.6.0 for buster, since less upstream delta is
  better to reduce maintain cost.
* tomoyo-tools is leaf package, no worries about breaking other packages'
  behavior :) (and it's stable enough, IMHO).

 The blocker for update is debdiff is huge.

> $ wc -l tomoyo.debdiff                                                                                                                                          
> 1528 tomoyo.debdiff

 However, most of above changes are almost same boring changes like this.

 diff -Nru tomoyo-tools-2.5.0-20170102/examples/candy.c tomoyo-tools-2.6.0-20190305/examples/candy.c
--- tomoyo-tools-2.5.0-20170102/examples/candy.c        2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/candy.c        2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * candy.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the

 URL change (use https), version and date update. I've striped down such
 things and diff size becomes just 255 lines (= upstream changes).

> $ wc -l tomoyo.diff 
> 255 tomoyo.diff

 And 1/3 of that is test file, remains are changes to update profile version.

diff --git a/kernel_test/tomoyo_bprm_test.c b/kernel_test/tomoyo_bprm_test.c
index c19d89e..1675ea6 100644
--- a/kernel_test/tomoyo_bprm_test.c
+++ b/kernel_test/tomoyo_bprm_test.c
@@ -178,6 +178,7 @@ int main(int argc, char *argv[])
 	ccs_test_init();
 	fprintf(domain_fp, "%s " BINDIR "/true\n", self_domain);
 	fprintf(domain_fp, "use_profile 255\n");
+	fprintf(domain_fp, "use_group 0\n");
 	fprintf(domain_fp, "select pid=%u\n", pid);
 	fprintf(domain_fp, "file read/write %s\n", proc_policy_domain_policy);
 	set_profile(3, "file::execute");
diff --git a/kernel_test/tomoyo_cond_test.c b/kernel_test/tomoyo_cond_test.c
index 123a2be..da5905d 100644
--- a/kernel_test/tomoyo_cond_test.c
+++ b/kernel_test/tomoyo_cond_test.c
@@ -388,7 +388,10 @@ static void stage_cond_test(void)
 int main(int argc, char *argv[])
 {
 	ccs_test_init();
-	fprintf(domain_fp, "ignore_global\n");
+	fprintf(domain_fp, "%s " BINDIR "/true\n", self_domain);
+	fprintf(domain_fp, "use_profile 255\n");
+	fprintf(domain_fp, "use_group 0\n");
+	fprintf(domain_fp, "%s\n", self_domain);
 	fprintf(domain_fp, "file read/write %s\n", proc_policy_domain_policy);
 	set_profile(3, "file::execute");
 	set_profile(3, "file::open");
diff --git a/kernel_test/tomoyo_new_file_test.c b/kernel_test/tomoyo_new_file_test.c
index 827c595..9c8ed87 100644
--- a/kernel_test/tomoyo_new_file_test.c
+++ b/kernel_test/tomoyo_new_file_test.c
@@ -118,6 +118,7 @@ static void stage_file_test(void)
 	size_t size = sizeof(buffer);
 	int pipe_fd[2] = { EOF, EOF };
 	int err = 0;
+	int flags;
 	int fd;
 	char pbuffer[1024];
 	struct stat sbuf;
@@ -184,6 +185,38 @@ static void stage_file_test(void)
 	write_domain_policy(policy, 1);
 	show_result(uselib("/tmp/uselib"), 0);
 
+	policy = "file write /dev/null";
+	fd = open("/dev/null", O_WRONLY);
+	show_result(fd, 0);
+	close(fd);
+	write_domain_policy(policy, 0);
+	fd = open("/dev/null", O_WRONLY);
+	show_result(fd, 1);
+	write_domain_policy(policy, 1);
+	flags = fcntl(fd, F_GETFL, 0) | O_APPEND;
+	policy = "file append /dev/null";
+	show_result(fcntl(fd, F_SETFL, flags), 0);
+	write_domain_policy(policy, 0);
+	show_result(fcntl(fd, F_SETFL, flags), 1);
+	write_domain_policy(policy, 1);
+	close(fd);
+
+	policy = "file append /dev/null";
+	fd = open("/dev/null", O_WRONLY | O_APPEND);
+	show_result(fd, 0);
+	close(fd);
+	write_domain_policy(policy, 0);
+	fd = open("/dev/null", O_WRONLY | O_APPEND);
+	show_result(fd, 1);
+	write_domain_policy(policy, 1);
+	flags = fcntl(fd, F_GETFL, 0) & ~O_APPEND;
+	policy = "file write /dev/null";
+	show_result(fcntl(fd, F_SETFL, flags), 0);
+	write_domain_policy(policy, 0);
+	show_result(fcntl(fd, F_SETFL, flags), 1);
+	write_domain_policy(policy, 1);
+	close(fd);
+
 	policy = "file execute " BINDIR "/true task.uid!=10 path1.parent.uid=0";
 	write_domain_policy(policy, 0);
 	fflush(stdout);
@@ -625,6 +658,7 @@ int main(int argc, char *argv[])
 	make_elf_lib();
 	fprintf(domain_fp, "%s " BINDIR "/true\n", self_domain);
 	fprintf(domain_fp, "use_profile 255\n");
+	fprintf(domain_fp, "use_group 0\n");
 	fprintf(domain_fp, "select pid=%u\n", pid);
 	fprintf(profile_fp, "255-PREFERENCE={ max_reject_log=1024 }\n");
 	stage_file_test();
diff --git a/sbin/tomoyo-init.c b/sbin/tomoyo-init.c
index e11472c..92428db 100644
--- a/sbin/tomoyo-init.c
+++ b/sbin/tomoyo-init.c
@@ -290,17 +290,9 @@ static void upgrade_profile(void)
 		} else
 			cp = buffer;
 		if (sscanf(cp, "PROFILE_VERSION=%u", &version) == 1)
-			in_section = version == 20100903;
-		if (!in_section)
-			continue;
-		if (sscanf(cp, "%u", &version) != 1) {
-			fprintf(fp_out, "%s PROFILE_VERSION=20110903\n", ns);
-			continue;
-		}
-		fprintf(fp_out, "%s %u-CONFIG::network={ mode=disabled }\n",
-			ns, version);
-		fprintf(fp_out, "%s %u-CONFIG::misc={ mode=disabled }\n",
-			ns, version);
+			in_section = version == 20110903;
+		if (in_section && sscanf(cp, "%u", &version) != 1)
+			fprintf(fp_out, "%s PROFILE_VERSION=20150505\n", ns);
 	}
 	fclose(fp_in);
 	fclose(fp_out);
diff --git a/usr_lib_tomoyo/init_policy.c b/usr_lib_tomoyo/init_policy.c
index bd836c6..e5cd87d 100644
--- a/usr_lib_tomoyo/init_policy.c
+++ b/usr_lib_tomoyo/init_policy.c
@@ -924,7 +924,7 @@ static void make_profile(void)
 	fprintf(stderr, "Creating default profile... ");
 	if (file_only_profile)
 		file_only = "::file";
-	fprintf(fp, "PROFILE_VERSION=20110903\n");
+	fprintf(fp, "PROFILE_VERSION=20150505\n");
 	fprintf(fp, "0-COMMENT=-----Disabled Mode-----\n"
 		"0-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"0-CONFIG%s={ mode=disabled grant_log=%s reject_log=%s }\n",
@@ -951,7 +951,7 @@ static void make_profile(void)
 /* Which profile number does <kernel> domain use? */
 static unsigned char default_profile = 0;
 /* Which ACL group does <kernel> domain use? */
-static unsigned char default_group = 0;
+static _Bool use_group[256] = { };
 
 /**
  * make_domain_policy - Make /etc/tomoyo/policy/current/domain_policy.conf .
@@ -961,6 +961,7 @@ static unsigned char default_group = 0;
 static void make_domain_policy(void)
 {
 	FILE *fp;
+	int i;
 	if (!chdir_policy())
 		return;
 	if (!access("domain_policy.conf", R_OK))
@@ -971,8 +972,10 @@ static void make_domain_policy(void)
 		return;
 	}
 	fprintf(stderr, "Creating domain policy... ");
-	fprintf(fp, "<kernel>\nuse_profile %u\nuse_group %u\n",
-		default_profile, default_group);
+	fprintf(fp, "<kernel>\nuse_profile %u\n", default_profile);
+	for (i = 0; i < 256; i++)
+		if (use_group[i])
+			fprintf(fp, "use_group %u\n", i);
 	close_file(fp, 1, "domain_policy.tmp", "domain_policy.conf");
 }
 
@@ -1644,7 +1647,7 @@ int main(int argc, char *argv[])
 		} else if (!strncmp(arg, "use_profile=", 12)) {
 			default_profile = atoi(arg + 12);
 		} else if (!strncmp(arg, "use_group=", 10)) {
-			default_group = atoi(arg + 10);
+			use_group[(unsigned char) atoi(arg + 10)] = 1;
 		} else if (!strncmp(arg, "grant_log=", 10)) {
 			grant_log = arg + 10;
 		} else if (!strncmp(arg, "reject_log=", 11)) {
@@ -1658,6 +1661,11 @@ int main(int argc, char *argv[])
 	}
 	if (!dir)
 		dir = "/etc/tomoyo";
+	for (i = 0; i < 256; i++)
+		if (use_group[i])
+			break;
+	if (i == 256)
+		use_group[0] = 1;
 	policy_dir = strdup(dir);
 	memset(path, 0, sizeof(path));
 	make_policy_dir();
diff --git a/usr_sbin/editpolicy.c b/usr_sbin/editpolicy.c
index 24c8fcf..ac74264 100644
--- a/usr_sbin/editpolicy.c
+++ b/usr_sbin/editpolicy.c
@@ -2796,7 +2796,7 @@ static void add_entry(void)
 			fprintf(fp, "%s ", current_ns->name);
 		break;
 	case SCREEN_NS_LIST:
-		fprintf(fp, "%s PROFILE_VERSION=20100903\n", line);
+		fprintf(fp, "%s PROFILE_VERSION=20150505\n", line);
 		line[0] = '\0';
 		break;
 	default:
diff -Nru tomoyo-tools-2.5.0-20170102/debian/changelog tomoyo-tools-2.6.0-20190305/debian/changelog
--- tomoyo-tools-2.5.0-20170102/debian/changelog        2018-05-31 22:52:33.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/debian/changelog        2019-03-09 19:48:43.000000000 +0900
@@ -1,3 +1,19 @@
+tomoyo-tools (2.6.0-20190305-1) unstable; urgency=medium
+
+  * New upstream release 
+  * debian/control
+    - set Standards-Version: 4.3.0
+    - use dh12
+    - add Rules-Requires-Root: no
+  * debian/copyright
+    - update copyright year
+  * drop unnecessary debian/upstream/signing-key.pgp, we have .asc file
+
+  [ Ondřej Nový ]
+  * d/changelog: Remove trailing whitespaces
+
+ -- Hideki Yamane <henrich@debian.org>  Sat, 09 Mar 2019 19:48:43 +0900

 Anyway, here's a debdiff
------------------
diff -Nru tomoyo-tools-2.5.0-20170102/README.tomoyo tomoyo-tools-2.6.0-20190305/README.tomoyo
--- tomoyo-tools-2.5.0-20170102/README.tomoyo	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/README.tomoyo	2019-03-05 09:00:00.000000000 +0900
@@ -1,68 +1,12 @@
 About this package:
 
-This package contains userland programs for TOMOYO Linux version 2.5.
+This package contains userland programs for TOMOYO Linux version 2.6.
 This package is released under the GPLv2.
 
-http://tomoyo.osdn.jp/
+https://tomoyo.osdn.jp/
 
 ChangeLog:
 
-Version 2.5.0   2011/09/29   Major update release.
+Version 2.6.0   2019/03/05   Major update release.
 
-  Rebased using ccs-tools-1.8.3.
-
-Version 2.5.0p1 2011/10/25   Bug fix release.
-
-  /usr/sbin/tomoyo-queryd
-    Use query id rather than global PID when reading or updating target
-    process's domain policy.
-
-  /usr/lib/tomoyo/init_policy
-    Add "socket:[family=\\$:type=\\$:protocol=\\$]" to ANY_PATHNAME group.
-
-Version 2.5.0p2 2012/04/14   Bug fix release.
-
-  /sbin/tomoyo-init
-    Parse statistics lines correctly.
-
-  /usr/sbin/tomoyo-editpolicy
-    Print number of selected entries if any.
-
-  /usr/lib/libtomoyotools.so
-    Fix IP address parsing.
-
-Version 2.5.0p3 2012/08/05   Bug fix release.
-
-  /usr/sbin/tomoyo-checkpolicy
-    Fix namespace prefix parsing in exception policy.
-
-  Rename manpage for init_policy to tomoyo_init_policy
-  (to allow parallel installation of ccs-tools package).
-
-Version 2.5.0p4 2013/02/14   Packaging fix release.
-
-  Change Makefile's build flags, as suggested by Simon Ruderich and Hideki
-  Yamane. (Debian bug 674723)
-
-  Change / to /* in rpm's %files section because Fedora 18 complains conflicts.
-
-Version 2.5.0p5 2013/04/06   Packaging fix release.
-
-  Fix compile warning from clang.
-
-Version 2.5.0p6 2014/01/05   Bug fix release.
-
-  /usr/lib/tomoyo/init_policy
-    Add path to systemd , as suggested by Shawn Landden.
-
-  /usr/sbin/tomoyo-queryd
-    Use poll() rather than select().
-
-Version 2.5.0p7 2014/06/01   Bug fix release.
-
-  /usr/sbin/tomoyo-editpolicy
-    Print "acl_group $N" correctly when using offline mode.
-
-Version 2.5.0p8 2017/01/02   Bug fix release.
-
-  Rebase to ccs-tools 1.8.5-2.
+  Adjust to TOMOYO 2.6.
diff -Nru tomoyo-tools-2.5.0-20170102/debian/changelog tomoyo-tools-2.6.0-20190305/debian/changelog
--- tomoyo-tools-2.5.0-20170102/debian/changelog	2018-05-31 22:52:33.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/debian/changelog	2019-03-09 19:48:43.000000000 +0900
@@ -1,3 +1,19 @@
+tomoyo-tools (2.6.0-20190305-1) unstable; urgency=medium
+
+  * New upstream release 
+  * debian/control
+    - set Standards-Version: 4.3.0
+    - use dh12
+    - add Rules-Requires-Root: no
+  * debian/copyright
+    - update copyright year
+  * drop unnecessary debian/upstream/signing-key.pgp, we have .asc file
+
+  [ Ondřej Nový ]
+  * d/changelog: Remove trailing whitespaces
+
+ -- Hideki Yamane <henrich@debian.org>  Sat, 09 Mar 2019 19:48:43 +0900
+
 tomoyo-tools (2.5.0-20170102-4) unstable; urgency=medium
 
   * debian/watch
@@ -11,7 +27,7 @@
 tomoyo-tools (2.5.0-20170102-3) unstable; urgency=medium
 
   * debian/copyright
-    - update copyright year and use https 
+    - update copyright year and use https
   * debian/control
     - move Vcs-* to salsa.debian.org
     - set debhelper (>= 11)
@@ -53,7 +69,7 @@
 
 tomoyo-tools (2.5.0-20140601-7) unstable; urgency=medium
 
-  * add debian/po/pt_BR.po (Closes: #835359) 
+  * add debian/po/pt_BR.po (Closes: #835359)
   * debian/control
     - set Standards-Version: 3.9.8
 
@@ -61,14 +77,14 @@
 
 tomoyo-tools (2.5.0-20140601-6) unstable; urgency=medium
 
-  * fix debian/tomoyo-tools.post{inst,rm} to work  
+  * fix debian/tomoyo-tools.post{inst,rm} to work
     Thanks to upstream to point it out.
 
  -- Hideki Yamane <henrich@debian.org>  Sun, 03 Jan 2016 12:08:23 +0900
 
 tomoyo-tools (2.5.0-20140601-5) unstable; urgency=medium
 
-  * update debian/watch 
+  * update debian/watch
   * debian/copyright
     - convert to copyright format 1.0
 
@@ -77,7 +93,7 @@
 tomoyo-tools (2.5.0-20140601-4) unstable; urgency=medium
 
   * debian/control
-    - update Vcs-* 
+    - update Vcs-*
     - update Homepage
   * debian/tomoyo-tools.post{inst,rm}
     - fix "command-with-path-in-maintainer-script"
@@ -95,20 +111,20 @@
 tomoyo-tools (2.5.0-20140601-2) unstable; urgency=medium
 
   * debian/po
-    - add nl.po: thanks to Frans Spiesschaert <Frans.Spiesschaert@yucom.be> 
+    - add nl.po: thanks to Frans Spiesschaert <Frans.Spiesschaert@yucom.be>
       (Closes: #766536)
 
  -- Hideki Yamane <henrich@debian.org>  Sat, 01 Nov 2014 13:48:09 +0900
 
 tomoyo-tools (2.5.0-20140601-1) unstable; urgency=medium
 
-  * Imported Upstream version 2.5.0-20140601 
+  * Imported Upstream version 2.5.0-20140601
 
  -- Hideki Yamane <henrich@debian.org>  Mon, 09 Jun 2014 06:56:08 +0900
 
 tomoyo-tools (2.5.0-20140105-2) unstable; urgency=medium
 
-  * move upstream pgp key to debian/upstream/signing-key.pgp 
+  * move upstream pgp key to debian/upstream/signing-key.pgp
   * debian/tomoyo-post{inst,rm}
     - fix "double entry of tomoyo for grub menu" (Closes: #717326)
       Thanks to Osamu Aoki <osamu@debian.org> for the patch
@@ -140,7 +156,7 @@
 
 tomoyo-tools (2.5.0-20130406-2) unstable; urgency=low
 
-  * Upload to unstable 
+  * Upload to unstable
 
  -- Hideki Yamane <henrich@debian.org>  Tue, 07 May 2013 13:15:45 +0900
 
@@ -148,7 +164,7 @@
 
   * New upstream release
   * debian/watch
-    - update it to deal with upstream page's change 
+    - update it to deal with upstream page's change
 
  -- Hideki Yamane <henrich@debian.org>  Sun, 07 Apr 2013 04:46:41 +0900
 
@@ -156,7 +172,7 @@
 
   * debian/tomoyo-tools.postinst
     - fix to exec init_policy
-    - care other grub parameter 
+    - care other grub parameter
     - print message if grub environment doesn't exist
   * debian/control
     - set Standards-Version: 3.9.4
@@ -213,7 +229,7 @@
     - exec debconf-updatepo in override_dh_clean
   * debian/tomoyo-tools.{pre,post}{inst,rm}
     - add stat.conf to CONFFILE
-    - rename to tomoyo-tools.* 
+    - rename to tomoyo-tools.*
   * With this release, you can enable tomoyo automatically with debconf.
     It set /etc/default/grub and exec update-grub.
     - debian/tomoyo-tools.post{inst,rm}
@@ -223,7 +239,7 @@
     - debian/control
       + add "Build-Depends: po-debconf" and "Pre-Depends: debconf"
     - debian/README.Debian
-      + update it 
+      + update it
   * debian/{tomoyo-tools,libtomoyotools3}.lintian-overrides
     - add it to override "no-upstream-changelog" warning, upstream changelog
       is provided as README.tomoyo file
@@ -272,14 +288,14 @@
 
 tomoyo-tools (2.4.0-20111025-2) unstable; urgency=low
 
-  * Upload to unstable 
+  * Upload to unstable
 
  -- Hideki Yamane <henrich@debian.org>  Sun, 11 Dec 2011 21:47:41 +0900
 
 tomoyo-tools (2.4.0-20111025-1) experimental; urgency=low
 
   * New upstream release (Closes: #651267)
-    - deal with /run transition (Closes: #644328)  
+    - deal with /run transition (Closes: #644328)
   * debian/patches
     - drop ld--as-needed.patch as merged to upstream
   * debian/control,libtomoyotools2.{symbols,install}
@@ -293,7 +309,7 @@
 tomoyo-tools (2.3.0-20100820-4) unstable; urgency=low
 
   * debian/control
-    - once remove Recommends: field, Thanks to Piotr Engelking 
+    - once remove Recommends: field, Thanks to Piotr Engelking
       <inkerman42@gmail.com> (Closes: #629494)
 
  -- Hideki Yamane <henrich@debian.org>  Sun, 25 Sep 2011 19:27:39 +0900
@@ -301,14 +317,14 @@
 tomoyo-tools (2.3.0-20100820-3) unstable; urgency=low
 
   * debian/postinst,postrm
-    - make sure to remove meminfo.conf 
+    - make sure to remove meminfo.conf
 
  -- Hideki Yamane <henrich@debian.org>  Sun, 25 Sep 2011 01:18:06 +0900
 
 tomoyo-tools (2.3.0-20100820-2) unstable; urgency=low
 
   * debian/control
-    - set Architecture: linux-any 
+    - set Architecture: linux-any
     - set Standards-Version: 3.9.2
     - drop "Ritesh Sarraf <rrs@debian.org>" from uploaders, thanks.
   * debian/patches
@@ -321,16 +337,16 @@
 
 tomoyo-tools (2.3.0-20100820-1) unstable; urgency=low
 
-  * New Upstream Release 
-  * Add a get-orig-source target 
+  * New Upstream Release
+  * Add a get-orig-source target
     - Update debian/watch file
     - Add target to debian/rules file
-  * Add debian/preinst to handle upgrade from 2.2.x to 2.3.x 
-  * Add help2man to build dependency 
-  * Add new library package libtomoyotools1 
-  * Bump Standards Version to 3.9.1 (No changes required) 
-  * Add linux-image-2.6 into Recommends 
-  * Add debian/NEWS 
+  * Add debian/preinst to handle upgrade from 2.2.x to 2.3.x
+  * Add help2man to build dependency
+  * Add new library package libtomoyotools1
+  * Bump Standards Version to 3.9.1 (No changes required)
+  * Add linux-image-2.6 into Recommends
+  * Add debian/NEWS
 
  -- Ritesh Raj Sarraf <rrs@debian.org>  Sun, 13 Feb 2011 23:15:35 +0530
 
@@ -352,14 +368,14 @@
 
   [ Ritesh Raj Sarraf ]
   * Update official Debian ID for maintenance
-  * Remove the DM-Upload-Allowed: yes field since we both are DDs now 
-  * Since upstream does not ship a changelog, use the debian changelog 
-  * Add README.Debian and provide a brief explanation on how to enable tomoyo 
+  * Remove the DM-Upload-Allowed: yes field since we both are DDs now
+  * Since upstream does not ship a changelog, use the debian changelog
+  * Add README.Debian and provide a brief explanation on how to enable tomoyo
 
  -- Ritesh Raj Sarraf <rrs@debian.org>  Mon, 10 May 2010 21:23:03 +0530
 
 tomoyo-tools (2.2.0-20090727-1) unstable; urgency=low
 
-  * Initial release 
+  * Initial release
 
  -- Hideki Yamane (Debian-JP) <henrich@debian.or.jp>  Sat, 06 Feb 2010 12:12:36 +0900
diff -Nru tomoyo-tools-2.5.0-20170102/debian/compat tomoyo-tools-2.6.0-20190305/debian/compat
--- tomoyo-tools-2.5.0-20170102/debian/compat	2018-05-31 22:52:33.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/debian/compat	1970-01-01 09:00:00.000000000 +0900
@@ -1 +0,0 @@
-11
diff -Nru tomoyo-tools-2.5.0-20170102/debian/control tomoyo-tools-2.6.0-20190305/debian/control
--- tomoyo-tools-2.5.0-20170102/debian/control	2018-05-31 22:52:33.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/debian/control	2019-03-09 19:48:43.000000000 +0900
@@ -3,10 +3,12 @@
 Priority: optional
 Maintainer: Hideki Yamane <henrich@debian.org>
 Homepage: https://tomoyo.osdn.jp/
-Build-Depends: debhelper (>= 11), libncurses5-dev, libreadline-dev, po-debconf
-Standards-Version: 4.1.4
+Build-Depends: debhelper (>= 12), debhelper-compat (= 12),
+               libncurses5-dev, libreadline-dev, po-debconf
+Standards-Version: 4.3.0
 Vcs-Git: https://salsa.debian.org/debian/tomoyo-tools.git
 Vcs-Browser: https://salsa.debian.org/debian/tomoyo-tools
+Rules-Requires-Root: no
 
 Package: tomoyo-tools
 Architecture: linux-any
diff -Nru tomoyo-tools-2.5.0-20170102/debian/copyright tomoyo-tools-2.6.0-20190305/debian/copyright
--- tomoyo-tools-2.5.0-20170102/debian/copyright	2018-05-31 22:52:33.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/debian/copyright	2019-03-09 19:48:43.000000000 +0900
@@ -5,11 +5,11 @@
 Source: https://osdn.net/projects/tomoyo/releases/p9818
 
 Files: *
-Copyright: 2009-2017 NTT DATA CORPORATION
+Copyright: 2009-2019 NTT DATA CORPORATION
 License: GPL-2
 
 Files: debian/*
-Copyright: 2009-2018 Hideki Yamane <henrich@debian.org>
+Copyright: 2009-2019 Hideki Yamane <henrich@debian.org>
 License: GPL-2
 
 License: GPL-2
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/debian/upstream/signing-key.pgp と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/debian/upstream/signing-key.pgp は異なります
diff -Nru tomoyo-tools-2.5.0-20170102/examples/candy.c tomoyo-tools-2.6.0-20190305/examples/candy.c
--- tomoyo-tools-2.5.0-20170102/examples/candy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/candy.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * candy.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/chaplet.c tomoyo-tools-2.6.0-20190305/examples/chaplet.c
--- tomoyo-tools-2.5.0-20170102/examples/chaplet.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/chaplet.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * chaplet.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/checktoken.c tomoyo-tools-2.6.0-20190305/examples/checktoken.c
--- tomoyo-tools-2.5.0-20170102/examples/checktoken.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/checktoken.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * checktoken.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/env_chk.c tomoyo-tools-2.6.0-20190305/examples/env_chk.c
--- tomoyo-tools-2.5.0-20170102/examples/env_chk.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/env_chk.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/falsh.c tomoyo-tools-2.6.0-20190305/examples/falsh.c
--- tomoyo-tools-2.5.0-20170102/examples/falsh.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/falsh.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * falsh.c
  *
  * A tiny shell without built-in commands.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is intended to provide a login shell
  * to allow users do extra authentications (CERBERUS) safely.
diff -Nru tomoyo-tools-2.5.0-20170102/examples/from-where.c tomoyo-tools-2.6.0-20190305/examples/from-where.c
--- tomoyo-tools-2.5.0-20170102/examples/from-where.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/from-where.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/gettoken.c tomoyo-tools-2.6.0-20190305/examples/gettoken.c
--- tomoyo-tools-2.5.0-20170102/examples/gettoken.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/gettoken.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * gettoken.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/groovy.c tomoyo-tools-2.6.0-20190305/examples/groovy.c
--- tomoyo-tools-2.5.0-20170102/examples/groovy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/groovy.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * groovy.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/honey.c tomoyo-tools-2.6.0-20190305/examples/honey.c
--- tomoyo-tools-2.5.0-20170102/examples/honey.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/honey.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * honey.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/mailauth.c tomoyo-tools-2.6.0-20190305/examples/mailauth.c
--- tomoyo-tools-2.5.0-20170102/examples/mailauth.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/mailauth.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * mailauth.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/proxy.c tomoyo-tools-2.6.0-20190305/examples/proxy.c
--- tomoyo-tools-2.5.0-20170102/examples/proxy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/proxy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This tool is intended to limit local port numbers that clients
  * will use when connecting to servers, so that servers can enforce
diff -Nru tomoyo-tools-2.5.0-20170102/examples/statvfs.c tomoyo-tools-2.6.0-20190305/examples/statvfs.c
--- tomoyo-tools-2.5.0-20170102/examples/statvfs.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/statvfs.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/examples/timeauth.c tomoyo-tools-2.6.0-20190305/examples/timeauth.c
--- tomoyo-tools-2.5.0-20170102/examples/timeauth.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/examples/timeauth.c	2019-03-05 09:00:00.000000000 +0900
@@ -2,11 +2,11 @@
  * timeauth.c
  *
  * An example program for CERBERUS.
- * ( http://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
+ * ( https://osdn.jp/projects/tomoyo/document/winf2005-en.pdf )
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/arglog.c tomoyo-tools-2.6.0-20190305/kernel_test/arglog.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/arglog.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/arglog.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/dummyfs.c tomoyo-tools-2.6.0-20190305/kernel_test/dummyfs.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/dummyfs.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/dummyfs.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This dummy filesystem is for 2.6.29. Build with "obj-y += dummyfs.o".
  *
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/generate_execve_log.c tomoyo-tools-2.6.0-20190305/kernel_test/generate_execve_log.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/generate_execve_log.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/generate_execve_log.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/include.h tomoyo-tools-2.6.0-20190305/kernel_test/include.h
--- tomoyo-tools-2.5.0-20170102/kernel_test/include.h	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/include.h	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/newns.c tomoyo-tools-2.6.0-20190305/kernel_test/newns.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/newns.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/newns.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/patterntest.c tomoyo-tools-2.6.0-20190305/kernel_test/patterntest.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/patterntest.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/patterntest.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -459,28 +459,28 @@
 	{ "pipe:[12345]", "pipe:[\\$]", 1 },
 	{ "socket:[family=1:type=2:protocol=3]",
 	  "socket:[family=1:type=2:protocol=\\$]", 1 },
-	{ "http://tomoyo.osdn.jp/";, "\\*/\\*/\\*/", 1 },
-	{ "http://tomoyo.osdn.jp/index.html";, "\\*/\\*/\\*/\\*", 1 },
-	{ "http://tomoyo.osdn.jp/index.html";,
+	{ "https://tomoyo.osdn.jp/";, "\\*/\\*/\\*/", 1 },
+	{ "https://tomoyo.osdn.jp/index.html";, "\\*/\\*/\\*/\\*", 1 },
+	{ "https://tomoyo.osdn.jp/index.html";,
 	  "\\*/\\*/\\*/\\*\\*\\@\\*\\@", 1 },
-	{ "http://tomoyo.osdn.jp/index.html";,
+	{ "https://tomoyo.osdn.jp/index.html";,
 	  "\\*/\\@\\*/\\*\\@/\\*\\@\\*\\@\\*", 1 },
-	{ "http://tomoyo.osdn.jp/1.7/index.html";,
-	  "http://\\{\\*\\}/\\@.html";, 1 },
-	{ "http://tomoyo.osdn.jp/index.html";,
+	{ "https://tomoyo.osdn.jp/1.7/index.html";,
+	  "https://\\{\\*\\}/\\@.html";, 1 },
+	{ "https://tomoyo.osdn.jp/index.html";,
 	  "\\*://\\@.osdn.jp/\\*", 1 },
-	{ "http://tomoyo.osdn.jp/index.html";,
+	{ "https://tomoyo.osdn.jp/index.html";,
 	  "\\*://\\@.osdn.jp/\\*", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
 	  "ccs-patch/security/ccsecurity/?root=tomoyo",
 	  "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
 	  "ccs-patch/security/?root=tomoyo",
 	  "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
 	  "ccs-patch/?root=tomoyo",
 	  "\\*://\\@osdn.jp/\\{\\*\\}/?root=tomoyo", 1 },
-	{ "http://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
+	{ "https://osdn.jp/projects/tomoyo/svn/view/trunk/1.7.x/";
 	  "/ccs-patch///security//ccsecurity///?root=tomoyo",
 	  "\\*://\\@osdn.jp/\\{\\*\\-.\\-..\\-\\*%\\*\\}/"
 	  "?root=tomoyo\\*\\*", 1 },
@@ -492,9 +492,9 @@
 	{ BINDIR "/", BINDIR "/\\*", 0 },
 	{ BINDIR "/", BINDIR "/\\@", 0 },
 	{ BINDIR "/", BINDIR "/\\@\\@", 0 },
-	{ "http://tomoyo.osdn.jp/";, "\\*/\\*/\\*/\?", 0 },
-	{ "http://tomoyo.osdn.jp/index.html";, "\\*/\\*/\\*/\\@", 0 },
-	{ "http://tomoyo.osdn.jp/index.html";, "http://\\*/\\@";, 0 },
+	{ "https://tomoyo.osdn.jp/";, "\\*/\\*/\\*/\?", 0 },
+	{ "https://tomoyo.osdn.jp/index.html";, "\\*/\\*/\\*/\\@", 0 },
+	{ "https://tomoyo.osdn.jp/index.html";, "https://\\*/\\@";, 0 },
 	{ "socket:[family=1:type=2:protocol=3]",
 	  "/\\{\\*\\}/socket:[\\*]", 0 },
 	{ NULL, NULL, 0 }
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/testall.sh tomoyo-tools-2.6.0-20190305/kernel_test/testall.sh
--- tomoyo-tools-2.5.0-20170102/kernel_test/testall.sh	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/testall.sh	2019-03-05 09:00:00.000000000 +0900
@@ -4,7 +4,7 @@
 #
 # Copyright (C) 2005-2011  NTT DATA CORPORATION
 #
-# Version: 2.5.0   2011/09/29
+# Version: 2.6.0   2019/03/05
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_accept_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_accept_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_accept_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_accept_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_argv0_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_argv0_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_argv0_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_argv0_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_bprm_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_bprm_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_bprm_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_bprm_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -178,6 +178,7 @@
 	ccs_test_init();
 	fprintf(domain_fp, "%s " BINDIR "/true\n", self_domain);
 	fprintf(domain_fp, "use_profile 255\n");
+	fprintf(domain_fp, "use_group 0\n");
 	fprintf(domain_fp, "select pid=%u\n", pid);
 	fprintf(domain_fp, "file read/write %s\n", proc_policy_domain_policy);
 	set_profile(3, "file::execute");
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_cond_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_cond_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_cond_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_cond_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -388,7 +388,10 @@
 int main(int argc, char *argv[])
 {
 	ccs_test_init();
-	fprintf(domain_fp, "ignore_global\n");
+	fprintf(domain_fp, "%s " BINDIR "/true\n", self_domain);
+	fprintf(domain_fp, "use_profile 255\n");
+	fprintf(domain_fp, "use_group 0\n");
+	fprintf(domain_fp, "%s\n", self_domain);
 	fprintf(domain_fp, "file read/write %s\n", proc_policy_domain_policy);
 	set_profile(3, "file::execute");
 	set_profile(3, "file::open");
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_env_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_env_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_env_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_env_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_file_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_file_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_file_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_file_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_filesystem_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_filesystem_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_filesystem_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_filesystem_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2012/02/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_network_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_network_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_network_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_network_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_new_file_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_new_file_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_new_file_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_new_file_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -118,6 +118,7 @@
 	size_t size = sizeof(buffer);
 	int pipe_fd[2] = { EOF, EOF };
 	int err = 0;
+	int flags;
 	int fd;
 	char pbuffer[1024];
 	struct stat sbuf;
@@ -184,6 +185,38 @@
 	write_domain_policy(policy, 1);
 	show_result(uselib("/tmp/uselib"), 0);
 
+	policy = "file write /dev/null";
+	fd = open("/dev/null", O_WRONLY);
+	show_result(fd, 0);
+	close(fd);
+	write_domain_policy(policy, 0);
+	fd = open("/dev/null", O_WRONLY);
+	show_result(fd, 1);
+	write_domain_policy(policy, 1);
+	flags = fcntl(fd, F_GETFL, 0) | O_APPEND;
+	policy = "file append /dev/null";
+	show_result(fcntl(fd, F_SETFL, flags), 0);
+	write_domain_policy(policy, 0);
+	show_result(fcntl(fd, F_SETFL, flags), 1);
+	write_domain_policy(policy, 1);
+	close(fd);
+
+	policy = "file append /dev/null";
+	fd = open("/dev/null", O_WRONLY | O_APPEND);
+	show_result(fd, 0);
+	close(fd);
+	write_domain_policy(policy, 0);
+	fd = open("/dev/null", O_WRONLY | O_APPEND);
+	show_result(fd, 1);
+	write_domain_policy(policy, 1);
+	flags = fcntl(fd, F_GETFL, 0) & ~O_APPEND;
+	policy = "file write /dev/null";
+	show_result(fcntl(fd, F_SETFL, flags), 0);
+	write_domain_policy(policy, 0);
+	show_result(fcntl(fd, F_SETFL, flags), 1);
+	write_domain_policy(policy, 1);
+	close(fd);
+
 	policy = "file execute " BINDIR "/true task.uid!=10 path1.parent.uid=0";
 	write_domain_policy(policy, 0);
 	fflush(stdout);
@@ -625,6 +658,7 @@
 	make_elf_lib();
 	fprintf(domain_fp, "%s " BINDIR "/true\n", self_domain);
 	fprintf(domain_fp, "use_profile 255\n");
+	fprintf(domain_fp, "use_group 0\n");
 	fprintf(domain_fp, "select pid=%u\n", pid);
 	fprintf(profile_fp, "255-PREFERENCE={ max_reject_log=1024 }\n");
 	stage_file_test();
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_new_network_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_new_network_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_new_network_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_new_network_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_new_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_new_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_new_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_new_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_policy_io_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_policy_io_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_policy_io_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_policy_io_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_policy_memory_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_policy_memory_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_policy_memory_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_policy_memory_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * Usage: Run this program using init= boot option.
  *
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_rewrite_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_rewrite_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_rewrite_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_rewrite_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_transition_test.c tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_transition_test.c
--- tomoyo-tools-2.5.0-20170102/kernel_test/tomoyo_transition_test.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/kernel_test/tomoyo_transition_test.c	2019-03-05 09:00:00.000000000 +0900
@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/12/13
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/tomoyo-tools.spec tomoyo-tools-2.6.0-20190305/tomoyo-tools.spec
--- tomoyo-tools-2.5.0-20170102/tomoyo-tools.spec	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/tomoyo-tools.spec	2019-03-05 09:00:00.000000000 +0900
@@ -1,8 +1,8 @@
-Summary: Userspace tools for TOMOYO Linux 2.5.x
+Summary: Userspace tools for TOMOYO Linux 2.6.x
 
 Name: tomoyo-tools
-Version: 2.5.0
-Release: 9
+Version: 2.6.0
+Release: 1
 License: GPL
 Group: System Environment/Kernel
 ExclusiveOS: Linux
@@ -15,13 +15,13 @@
 ##
 # BuildRequires: ncurses-devel
 Requires: ncurses
-Conflicts: tomoyo-tools < 2.5.0-9
+Conflicts: tomoyo-tools < 2.6.0-1
 
-Source0: http://osdn.dl.osdn.jp/tomoyo/53357/tomoyo-tools-2.5.0-20170102.tar.gz
+Source0: https://osdn.dl.osdn.jp/tomoyo/70710/tomoyo-tools-2.6.0-20190305.tar.gz
 
 %description
-This package contains userspace tools for administrating TOMOYO Linux 2.5.x.
-Please see http://tomoyo.osdn.jp/2.5/ for documentation.
+This package contains userspace tools for administrating TOMOYO Linux 2.6.x.
+Please see https://tomoyo.osdn.jp/2.6/ for documentation.
 
 %prep
 
@@ -52,6 +52,9 @@
 /usr/share/man/man8/*
 
 %changelog
+* Tue Mar 05 2019 2.6.0-1
+- Adjust to TOMOYO 2.6.
+
 * Mon Jan 02 2017 2.5.0-9
 - Rebase to ccs-tools 1.8.5-2.
 
diff -Nru tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/audit-exec-param.c tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/audit-exec-param.c
--- tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/audit-exec-param.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/audit-exec-param.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/convert-audit-log.c tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/convert-audit-log.c
--- tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/convert-audit-log.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/convert-audit-log.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/convert-exec-param.c tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/convert-exec-param.c
--- tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/convert-exec-param.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/convert-exec-param.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/init_policy.c tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/init_policy.c
--- tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/init_policy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/init_policy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -924,7 +924,7 @@
 	fprintf(stderr, "Creating default profile... ");
 	if (file_only_profile)
 		file_only = "::file";
-	fprintf(fp, "PROFILE_VERSION=20110903\n");
+	fprintf(fp, "PROFILE_VERSION=20150505\n");
 	fprintf(fp, "0-COMMENT=-----Disabled Mode-----\n"
 		"0-PREFERENCE={ max_audit_log=%u max_learning_entry=%u }\n"
 		"0-CONFIG%s={ mode=disabled grant_log=%s reject_log=%s }\n",
@@ -951,7 +951,7 @@
 /* Which profile number does <kernel> domain use? */
 static unsigned char default_profile = 0;
 /* Which ACL group does <kernel> domain use? */
-static unsigned char default_group = 0;
+static _Bool use_group[256] = { };
 
 /**
  * make_domain_policy - Make /etc/tomoyo/policy/current/domain_policy.conf .
@@ -961,6 +961,7 @@
 static void make_domain_policy(void)
 {
 	FILE *fp;
+	int i;
 	if (!chdir_policy())
 		return;
 	if (!access("domain_policy.conf", R_OK))
@@ -971,8 +972,10 @@
 		return;
 	}
 	fprintf(stderr, "Creating domain policy... ");
-	fprintf(fp, "<kernel>\nuse_profile %u\nuse_group %u\n",
-		default_profile, default_group);
+	fprintf(fp, "<kernel>\nuse_profile %u\n", default_profile);
+	for (i = 0; i < 256; i++)
+		if (use_group[i])
+			fprintf(fp, "use_group %u\n", i);
 	close_file(fp, 1, "domain_policy.tmp", "domain_policy.conf");
 }
 
@@ -1644,7 +1647,7 @@
 		} else if (!strncmp(arg, "use_profile=", 12)) {
 			default_profile = atoi(arg + 12);
 		} else if (!strncmp(arg, "use_group=", 10)) {
-			default_group = atoi(arg + 10);
+			use_group[(unsigned char) atoi(arg + 10)] = 1;
 		} else if (!strncmp(arg, "grant_log=", 10)) {
 			grant_log = arg + 10;
 		} else if (!strncmp(arg, "reject_log=", 11)) {
@@ -1658,6 +1661,11 @@
 	}
 	if (!dir)
 		dir = "/etc/tomoyo";
+	for (i = 0; i < 256; i++)
+		if (use_group[i])
+			break;
+	if (i == 256)
+		use_group[0] = 1;
 	policy_dir = strdup(dir);
 	memset(path, 0, sizeof(path));
 	make_policy_dir();
diff -Nru tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/tomoyo-editpolicy-agent.c tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/tomoyo-editpolicy-agent.c
--- tomoyo-tools-2.5.0-20170102/usr_lib_tomoyo/tomoyo-editpolicy-agent.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_lib_tomoyo/tomoyo-editpolicy-agent.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -2796,7 +2796,7 @@
 			fprintf(fp, "%s ", current_ns->name);
 		break;
 	case SCREEN_NS_LIST:
-		fprintf(fp, "%s PROFILE_VERSION=20100903\n", line);
+		fprintf(fp, "%s PROFILE_VERSION=20150505\n", line);
 		line[0] = '\0';
 		break;
 	default:
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy.h tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy.h
--- tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy.h	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy.h	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_color.c tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_color.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_color.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_color.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_keyword.c tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_keyword.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_keyword.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_keyword.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_optimizer.c tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_optimizer.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_optimizer.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_optimizer.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/readline.h tomoyo-tools-2.6.0-20190305/usr_sbin/readline.h
--- tomoyo-tools-2.5.0-20170102/usr_sbin/readline.h	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/readline.h	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-auditd.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-auditd.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-auditd.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-auditd.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-checkpolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-checkpolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-checkpolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-checkpolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-diffpolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-diffpolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-diffpolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-diffpolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-domainmatch.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-domainmatch.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-domainmatch.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-domainmatch.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-findtemp.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-findtemp.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-findtemp.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-findtemp.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-loadpolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-loadpolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-loadpolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-loadpolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-notifyd.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-notifyd.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-notifyd.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-notifyd.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-patternize.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-patternize.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-patternize.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-patternize.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-pstree.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-pstree.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-pstree.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-pstree.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-queryd.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-queryd.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-queryd.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-queryd.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2014/01/05
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-savepolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-savepolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-savepolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-savepolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-selectpolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-selectpolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-selectpolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-selectpolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-setlevel.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-setlevel.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-setlevel.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-setlevel.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-setprofile.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-setprofile.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-setprofile.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-setprofile.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-sortpolicy.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-sortpolicy.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyo-sortpolicy.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyo-sortpolicy.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0   2011/09/29
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyotools.c tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyotools.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyotools.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyotools.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyotools.h tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyotools.h
--- tomoyo-tools-2.5.0-20170102/usr_sbin/tomoyotools.h	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/tomoyotools.h	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2011  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2014/01/05
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-auditd.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-auditd.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-checkpolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-checkpolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-diffpolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-diffpolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-domainmatch.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-domainmatch.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-editpolicy-agent.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-editpolicy-agent.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-editpolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-editpolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-findtemp.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-findtemp.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-init.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-init.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-loadpolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-loadpolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-notifyd.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-notifyd.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-patternize.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-patternize.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-pstree.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-pstree.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-queryd.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-queryd.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-savepolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-savepolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-selectpolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-selectpolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-setlevel.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-setlevel.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-setprofile.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-setprofile.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo-sortpolicy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo-sortpolicy.8.gz は異なります
バイナリーファイル /tmp/uejWFnEgzf/tomoyo-tools-2.5.0-20170102/usr_share_man/man8/tomoyo_init_policy.8.gz と/tmp/rwHELmHlEO/tomoyo-tools-2.6.0-20190305/usr_share_man/man8/tomoyo_init_policy.8.gz は異なります
------------------


unblock tomoyo-tools/2.6.0-20190305-1

-- System Information:
Debian Release: buster/sid
  APT prefers unstable
  APT policy: (500, 'unstable'), (1, 'experimental')
Architecture: amd64 (x86_64)

Kernel: Linux 4.19.0-3-amd64 (SMP w/4 CPU cores)
Kernel taint flags: TAINT_OOT_MODULE, TAINT_UNSIGNED_MODULE
Locale: LANG=ja_JP.UTF-8, LC_CTYPE=ja_JP.UTF-8 (charmap=UTF-8), LANGUAGE=ja_JP.UTF-8 (charmap=UTF-8)
Shell: /bin/sh linked to /bin/dash
Init: systemd (via /run/systemd/system)
LSM: AppArmor: enabled

--- End Message ---
--- Begin Message ---
On Sat, 23 Mar 2019 17:28:27 +0000 Jonathan Wiltshire <jmw@debian.org> wrote:
> Control: tag -1 moreinfo
> Keeping close to upstream is useful, but the freeze policy is bug fixes
> only. This doesn't appear to fix any bugs, or have I misunderstood?

 Okay, it violates policy so should be rejected, sorry for the noise.


diff --git a/usr_sbin/editpolicy_offline.c b/usr_sbin/editpolicy_offline.c
index dcf5253..cf67b92 100644
--- a/usr_sbin/editpolicy_offline.c
+++ b/usr_sbin/editpolicy_offline.c
@@ -701,7 +701,7 @@ struct ccs_policy_namespace {
 	struct list_head acl_group[CCS_MAX_ACL_GROUPS];
 	/* List for connecting to ccs_namespace_list list. */
 	struct list_head namespace_list;
 	/* Profile version. Currently only 20110903 is supported. */
 	unsigned int profile_version;
 	/* Name of this namespace (e.g. "<kernel>", "</usr/sbin/httpd>" ). */
 	const char *name;
@@ -712,7 +712,8 @@ struct ccs_domain2_info {
 	struct list_head acl_info_list;
 	/* Name of this domain. Never NULL.          */
 	const struct ccs_path_info *domainname;
-	u8 group;          /* Group number to use.   */
+	/* Group numbers to use.   */
+	bool group[CCS_MAX_ACL_GROUPS];
 	u8 profile;        /* Profile number to use. */
 	bool is_deleted;   /* Delete flag.           */
 	bool flags[CCS_MAX_DOMAIN_INFO_FLAGS];
@@ -2325,7 +2326,7 @@ static struct ccs_policy_namespace *ccs_assign_namespace(const char *domainname)
 		name[len] = '\0';
 		entry->name = name;
 	}
-	entry->profile_version = 20110903;
+	entry->profile_version = 20150505;
 	for (len = 0; len < CCS_MAX_ACL_GROUPS; len++)
 		INIT_LIST_HEAD(&entry->acl_group[len]);
 	ccs_namespace_enabled = !list_empty(&ccs_namespace_list);
@@ -3374,14 +3375,6 @@ static void ccs_read_profile(void)
 				const u8 config = profile->config[i];
 				if (config == CCS_CONFIG_USE_DEFAULT)
 					continue;
-				/*
-				 * Don't print TOMOYO 2.5 entries when using
-				 * TOMOYO 2.4's profile.
-				 */
-				if (ns->profile_version < 20110903 &&
-				    i > CCS_MAC_FILE_PIVOT_ROOT && i !=
-				    CCS_MAX_MAC_INDEX + CCS_MAC_CATEGORY_FILE)
-					continue;
 				ccs_print_namespace(ns);
 				if (i < CCS_MAX_MAC_INDEX)
 					cprintf("%u-CONFIG::%s::%s", index,
@@ -3637,8 +3630,7 @@ static int ccs_write_domain(void)
 	}
 	if (sscanf(data, "use_group %u\n", &idx) == 1 &&
 	    idx < CCS_MAX_ACL_GROUPS) {
-		if (!is_delete)
-			domain->group = (u8) idx;
+		domain->group[idx] = !is_delete;
 		return 0;
 	}
 	for (idx = 0; idx < CCS_MAX_DOMAIN_INFO_FLAGS; idx++) {
@@ -4024,7 +4016,7 @@ static void ccs_read_domain(void)
 			if (domain->flags[i])
 				cprintf("%s", ccs_dif[i]);
 		for (i = 0; i < CCS_MAX_ACL_GROUPS; i++)
-			if (domain->group == i)
+			if (domain->group[i])
 				cprintf("use_group %u\n", i);
 		cprintf("\n");
 		ccs_read_domain2(&domain->acl_info_list);
@@ -701,7 +701,7 @@ struct ccs_policy_namespace {
 	/* List for connecting to ccs_namespace_list list. */
 	struct list_head namespace_list;
-	/* Profile version. Currently only 20110903 is supported. */
+	/* Profile version. Currently only 20150505 is supported. */
 	unsigned int profile_version;
 	/* Name of this namespace (e.g. "<kernel>", "</usr/sbin/httpd>" ). */

 For packaging changes, most of the changes are caused by "Remove trailing
 whitespaces".
  
diff -Nru tomoyo-tools-2.5.0-20170102/sbin/tomoyo-init.c tomoyo-tools-2.6.0-20190305/sbin/tomoyo-init.c
--- tomoyo-tools-2.5.0-20170102/sbin/tomoyo-init.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/sbin/tomoyo-init.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2012/04/14
+ * Version: 2.6.0   2019/03/05
  *
  * This program is executed automatically by kernel
  * when execution of /sbin/init is requested.
@@ -266,8 +266,8 @@
 }
 
 /*
  * Upgrade from TOMOYO 2.4's profile (PROFILE_VERSION=20100903) to TOMOYO 2.5's
  * profile (PROFILE_VERSION=20110903) as needed.
  */
 static void upgrade_profile(void)
 {
@@ -290,17 +290,9 @@
 		} else
 			cp = buffer;
 		if (sscanf(cp, "PROFILE_VERSION=%u", &version) == 1)
-			in_section = version == 20100903;
-		if (!in_section)
-			continue;
-		if (sscanf(cp, "%u", &version) != 1) {
-			fprintf(fp_out, "%s PROFILE_VERSION=20110903\n", ns);
-			continue;
-		}
-		fprintf(fp_out, "%s %u-CONFIG::network={ mode=disabled }\n",
-			ns, version);
-		fprintf(fp_out, "%s %u-CONFIG::misc={ mode=disabled }\n",
-			ns, version);
+			in_section = version == 20110903;
+		if (in_section && sscanf(cp, "%u", &version) != 1)
+			fprintf(fp_out, "%s PROFILE_VERSION=20150505\n", ns);
 	}
 	fclose(fp_in);
 	fclose(fp_out);
@@ -266,8 +266,8 @@
 
 /*
- * Upgrade from TOMOYO 2.4's profile (PROFILE_VERSION=20100903) to TOMOYO 2.5's
- * profile (PROFILE_VERSION=20110903) as needed.
+ * Upgrade from TOMOYO 2.5's profile (PROFILE_VERSION=20110903) to TOMOYO 2.6's
+ * profile (PROFILE_VERSION=20150505) as needed.
  */
 static void upgrade_profile(void)
diff -Nru tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_offline.c tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_offline.c
--- tomoyo-tools-2.5.0-20170102/usr_sbin/editpolicy_offline.c	2017-01-04 19:12:17.000000000 +0900
+++ tomoyo-tools-2.6.0-20190305/usr_sbin/editpolicy_offline.c	2019-03-05 09:00:00.000000000 +0900
@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 2.5.0+   2017/01/02
+ * Version: 2.6.0   2019/03/05
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License v2 as published by the
@@ -701,7 +701,7 @@
 	struct list_head acl_group[CCS_MAX_ACL_GROUPS];
 	/* List for connecting to ccs_namespace_list list. */
 	struct list_head namespace_list;
 	/* Profile version. Currently only 20110903 is supported. */
 	unsigned int profile_version;
 	/* Name of this namespace (e.g. "<kernel>", "</usr/sbin/httpd>" ). */
 	const char *name;
@@ -712,7 +712,8 @@
 	struct list_head acl_info_list;
 	/* Name of this domain. Never NULL.          */
 	const struct ccs_path_info *domainname;
-	u8 group;          /* Group number to use.   */
+	/* Group numbers to use.   */
+	bool group[CCS_MAX_ACL_GROUPS];
 	u8 profile;        /* Profile number to use. */
 	bool is_deleted;   /* Delete flag.           */
 	bool flags[CCS_MAX_DOMAIN_INFO_FLAGS];
@@ -1342,7 +1343,7 @@
  * @string: String representation for permissions in foo/bar/buz format.
  * @keyword: Keyword to find from @string/
  *
- * Returns ture if @keyword was found in @string, false otherwise.
+ * Returns true if @keyword was found in @string, false otherwise.
  *
  * This function assumes that strncmp(w1, w2, strlen(w1)) != 0 if w1 != w2.
  */
@@ -2325,7 +2326,7 @@
 		name[len] = '\0';
 		entry->name = name;
 	}
-	entry->profile_version = 20110903;
+	entry->profile_version = 20150505;
 	for (len = 0; len < CCS_MAX_ACL_GROUPS; len++)
 		INIT_LIST_HEAD(&entry->acl_group[len]);
 	ccs_namespace_enabled = !list_empty(&ccs_namespace_list);
@@ -3374,14 +3375,6 @@
 				const u8 config = profile->config[i];
 				if (config == CCS_CONFIG_USE_DEFAULT)
 					continue;
-				/*
-				 * Don't print TOMOYO 2.5 entries when using
-				 * TOMOYO 2.4's profile.
-				 */
-				if (ns->profile_version < 20110903 &&
-				    i > CCS_MAC_FILE_PIVOT_ROOT && i !=
-				    CCS_MAX_MAC_INDEX + CCS_MAC_CATEGORY_FILE)
-					continue;
 				ccs_print_namespace(ns);
 				if (i < CCS_MAX_MAC_INDEX)
 					cprintf("%u-CONFIG::%s::%s", index,
@@ -3637,8 +3630,7 @@
 	}
 	if (sscanf(data, "use_group %u\n", &idx) == 1 &&
 	    idx < CCS_MAX_ACL_GROUPS) {
-		if (!is_delete)
-			domain->group = (u8) idx;
+		domain->group[idx] = !is_delete;
 		return 0;
 	}
 	for (idx = 0; idx < CCS_MAX_DOMAIN_INFO_FLAGS; idx++) {
@@ -4024,7 +4016,7 @@
 			if (domain->flags[i])
 				cprintf("%s", ccs_dif[i]);
 		for (i = 0; i < CCS_MAX_ACL_GROUPS; i++)
-			if (domain->group == i)
+			if (domain->group[i])
 				cprintf("use_group %u\n", i);
 		cprintf("\n");
 		ccs_read_domain2(&domain->acl_info_list);
@@ -701,7 +701,7 @@
 	/* List for connecting to ccs_namespace_list list. */
 	struct list_head namespace_list;
-	/* Profile version. Currently only 20110903 is supported. */
+	/* Profile version. Currently only 20150505 is supported. */
 	unsigned int profile_version;
 	/* Name of this namespace (e.g. "<kernel>", "</usr/sbin/httpd>" ). */
-- 
Hideki Yamane <henrich@iijmio-mail.jp>

--- End Message ---

Reply to: